@@ -48,32 +48,18 @@ void AddToArchiveTest::testCompressHere_data()
     QTest::addColumn<qulonglong>("expectedNumberOfEntries");
 
     QTest::newRow("compress here (as TAR) - dir with files")
-        << QStringLiteral("tar.gz")
-        << Archive::Unencrypted
-        << QStringList {QFINDTESTDATA("data/testdir")}
-        << QStringLiteral("testdir.tar.gz")
-        << 3ULL;
+        << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdir")} << QStringLiteral("testdir.tar.gz") << 3ULL;
 
     QTest::newRow("compress here (as TAR) - dir with subdirs")
-        << QStringLiteral("tar.gz")
-        << Archive::Unencrypted
-        << QStringList {QFINDTESTDATA("data/testdirwithsubdirs")}
-        << QStringLiteral("testdirwithsubdirs.tar.gz")
-        << 8ULL;
+        << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdirwithsubdirs")}
+        << QStringLiteral("testdirwithsubdirs.tar.gz") << 8ULL;
 
     QTest::newRow("compress here (as TAR) - dir with empty subdir")
-        << QStringLiteral("tar.gz")
-        << Archive::Unencrypted
-        << QStringList {QFINDTESTDATA("data/testdirwithemptysubdir")}
-        << QStringLiteral("testdirwithemptysubdir.tar.gz")
-        << 4ULL;
+        << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdirwithemptysubdir")}
+        << QStringLiteral("testdirwithemptysubdir.tar.gz") << 4ULL;
 
     QTest::newRow("compress here (as TAR) - single file")
-        << QStringLiteral("tar.gz")
-        << Archive::Unencrypted
-        << QStringList {QFINDTESTDATA("data/testfile.txt")}
-        << QStringLiteral("testfile.tar.gz")
-        << 1ULL;
+        << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testfile.txt")} << QStringLiteral("testfile.tar.gz") << 1ULL;
 
     QTest::newRow("compress here (as TAR) - file + folder")
         << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdir"), QFINDTESTDATA("data/testfile.txt")}
@@ -82,7 +68,7 @@ void AddToArchiveTest::testCompressHere_data()
     QTest::newRow("compress here (as TAR) - files with same prefix")
         << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/textfile1.txt"), QFINDTESTDATA("data/textfile2.txt")}
         << QStringLiteral("textfile.tar.gz") << 2ULL;
-    
+
     QTest::newRow("compress here (as TAR) - files with same base name")
         << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testfile.txt"), QFINDTESTDATA("data/testfile.md")}
         << QStringLiteral("testfile.tar.gz") << 2ULL;
@@ -92,58 +78,33 @@ void AddToArchiveTest::testCompressHere_data()
         << QStringLiteral("Archive.tar.gz") << 2ULL;
 
     QTest::newRow("compress here (as TAR) - bug #362690")
-        << QStringLiteral("tar.gz")
-        << Archive::Unencrypted
-        << QStringList {QFINDTESTDATA("data/test-3.4.0")}
-        << QStringLiteral("test-3.4.0.tar.gz")
-        << 2ULL;
+        << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/test-3.4.0")} << QStringLiteral("test-3.4.0.tar.gz") << 2ULL;
 
     QTest::newRow("compress here (as TAR) - files with mimetypes but no extension (no infinite loop)")
-        << QStringLiteral("tar.gz")
-        << Archive::Unencrypted
-        << QStringList {QFINDTESTDATA("data/Makefile"), QFINDTESTDATA("data/README")}
-        << QStringLiteral("Archive.tar.gz")
-        << 2ULL;
+        << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/Makefile"), QFINDTESTDATA("data/README")}
+        << QStringLiteral("Archive.tar.gz") << 2ULL;
 
     if (!PluginManager().preferredWritePluginsFor(QMimeDatabase().mimeTypeForName(QStringLiteral("application/zip"))).isEmpty()) {
         QTest::newRow("compress here (as ZIP) - dir with files")
-            << QStringLiteral("zip")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testdir")}
-            << QStringLiteral("testdir.zip")
-            << 3ULL;
+            << QStringLiteral("zip") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdir")} << QStringLiteral("testdir.zip") << 3ULL;
 
         QTest::newRow("compress here (as ZIP) - dir with subdirs")
-            << QStringLiteral("zip")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testdirwithsubdirs")}
-            << QStringLiteral("testdirwithsubdirs.zip")
-            << 8ULL;
+            << QStringLiteral("zip") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdirwithsubdirs")}
+            << QStringLiteral("testdirwithsubdirs.zip") << 8ULL;
 
         QTest::newRow("compress here (as ZIP) - dir with empty subdir")
-            << QStringLiteral("zip")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testdirwithemptysubdir")}
-            << QStringLiteral("testdirwithemptysubdir.zip")
-            << 4ULL;
+            << QStringLiteral("zip") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdirwithemptysubdir")}
+            << QStringLiteral("testdirwithemptysubdir.zip") << 4ULL;
 
         QTest::newRow("compress here (as ZIP) - single file")
-            << QStringLiteral("zip")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testfile.txt")}
-            << QStringLiteral("testfile.zip")
-            << 1ULL;
+            << QStringLiteral("zip") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testfile.txt")} << QStringLiteral("testfile.zip") << 1ULL;
 
         QTest::newRow("compress here (as ZIP) - file + folder")
             << QStringLiteral("zip") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdir"), QFINDTESTDATA("data/testfile.txt")}
             << QStringLiteral("Archive.zip") << 4ULL;
 
         QTest::newRow("compress here (as TAR) - dir with special name (see #365798)")
-            << QStringLiteral("tar.gz")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/test%dir")}
-            << QStringLiteral("test%dir.tar.gz")
-            << 3ULL;
+            << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/test%dir")} << QStringLiteral("test%dir.tar.gz") << 3ULL;
 
     } else {
         qDebug() << "7z/zip executable not found in path. Skipping compress-here-(ZIP) tests.";
@@ -151,32 +112,18 @@ void AddToArchiveTest::testCompressHere_data()
 
     if (!PluginManager().preferredWritePluginsFor(QMimeDatabase().mimeTypeForName(QStringLiteral("application/vnd.rar"))).isEmpty()) {
         QTest::newRow("compress here (as RAR) - dir with files")
-            << QStringLiteral("rar")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testdir")}
-            << QStringLiteral("testdir.rar")
-            << 3ULL;
+            << QStringLiteral("rar") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdir")} << QStringLiteral("testdir.rar") << 3ULL;
 
         QTest::newRow("compress here (as RAR) - dir with subdirs")
-            << QStringLiteral("rar")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testdirwithsubdirs")}
-            << QStringLiteral("testdirwithsubdirs.rar")
-            << 8ULL;
+            << QStringLiteral("rar") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdirwithsubdirs")}
+            << QStringLiteral("testdirwithsubdirs.rar") << 8ULL;
 
         QTest::newRow("compress here (as RAR) - dir with empty subdir")
-            << QStringLiteral("rar")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testdirwithemptysubdir")}
-            << QStringLiteral("testdirwithemptysubdir.rar")
-            << 4ULL;
+            << QStringLiteral("rar") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdirwithemptysubdir")}
+            << QStringLiteral("testdirwithemptysubdir.rar") << 4ULL;
 
         QTest::newRow("compress here (as RAR) - single file")
-            << QStringLiteral("rar")
-            << Archive::Unencrypted
-            << QStringList {QFINDTESTDATA("data/testfile.txt")}
-            << QStringLiteral("testfile.rar")
-            << 1ULL;
+            << QStringLiteral("rar") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testfile.txt")} << QStringLiteral("testfile.rar") << 1ULL;
 
         QTest::newRow("compress here (as RAR) - file + folder")
             << QStringLiteral("rar") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testdir"), QFINDTESTDATA("data/testfile.txt")}
